@@ -25,22 +25,27 @@
 #include <config.h>
 #endif
 
+#include "glade-project-window.h"
+
+#include <gladeui/glade.h>
+#include <gladeui/glade-design-view.h>
+#include <gladeui/glade-binding.h>
+
 #include <string.h>
+#include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkstock.h>
 
-#include "glade.h"
-#include "glade-design-view.h"
-#include "glade-project-window.h"
-#include "glade-binding.h"
-
 #define GLADE_ACTION_GROUP_STATIC "GladeStatic"
 #define GLADE_ACTION_GROUP_PROJECT "GladeProject"
 #define GLADE_ACTION_GROUP_PROJECTS_LIST_MENU "GladeProjectsList"
 
 #define READONLY_INDICATOR (_("[Read Only]"))
 
+#define GLADE_URL_USER_MANUAL      "http://glade.gnome.org/manual/index.html"
+#define GLADE_URL_DEVELOPER_MANUAL "http://glade.gnome.org/docs/index.html"
+
 #define GLADE_PROJECT_WINDOW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object),  \
 					         GLADE_TYPE_PROJECT_WINDOW,              \
 					         GladeProjectWindowPrivate))
@@ -71,26 +76,116 @@ struct _GladeProjectWindowPrivate
 	GtkRecentManager *recent_manager;
 	GtkWidget *recent_menu;
 
-	GtkWidget *console;
-
 	gchar *default_path; /* the default path for open/save operations */
 	
 	GtkToggleToolButton *selector_button; /* the widget selector button (replaces the one in the palette) */
 	
 };
 
-const gint   GLADE_WIDGET_TREE_WIDTH      = 230;
-const gint   GLADE_WIDGET_TREE_HEIGHT     = 300;
-const gint   GLADE_PALETTE_DEFAULT_HEIGHT = 450;
-
-static gpointer parent_class = NULL;
+static GladeAppClass *parent_class = NULL;
 
 static void gpw_refresh_undo_redo (GladeProjectWindow *gpw);
 
 static void gpw_recent_chooser_item_activated_cb (GtkRecentChooser *chooser, GladeProjectWindow *gpw);
 
+
 G_DEFINE_TYPE(GladeProjectWindow, glade_project_window, GLADE_TYPE_APP)
 
+static void
+about_dialog_activate_link_func (GtkAboutDialog *dialog, const gchar *link, GladeProjectWindow *gpw)
+{
+	GtkWidget *warning_dialog;
+	gboolean retval;
+	
+	retval = glade_util_url_show (link);
+	
+	if (!retval)
+	{
+		warning_dialog = gtk_message_dialog_new (GTK_WINDOW (gpw->priv->window),
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_WARNING,
+						 GTK_BUTTONS_OK,
+						 _("Could not display the URL '%s'"),
+						 link);
+						 
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (warning_dialog),
+							  _("No suitable web browser executable could be found."));
+						 	
+		gtk_window_set_title (GTK_WINDOW (warning_dialog), "");
+
+		g_signal_connect_swapped (warning_dialog, "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  dialog);
+
+		gtk_widget_show (warning_dialog);
+	}	
+
+}
+
+/* locates the help file "glade.xml" with respect to current locale */
+static gchar*
+locate_help_file ()
+{
+	const gchar* const* locales = g_get_language_names ();
+
+	/* check if user manual has been installed, if not, GLADE_GNOMEHELPDIR is empty */
+	if (strlen (GLADE_GNOMEHELPDIR) == 0)
+		return NULL;
+
+	for (; *locales; locales++)
+	{
+		gchar *path;
+		
+		path = g_build_path (G_DIR_SEPARATOR_S, GLADE_GNOMEHELPDIR, "glade", *locales, "glade.xml", NULL);
+
+		if (g_file_test (path, G_FILE_TEST_EXISTS))
+		{
+			return (path);
+		}
+		g_free (path);
+	}
+	
+	return NULL;
+}
+
+static gboolean
+glade_project_window_help_show (const gchar *link_id)
+{
+	gchar *file, *url, *command;
+	gboolean retval;
+	gint exit_status = -1;
+	GError *error = NULL; 	
+
+	file = locate_help_file ();
+	if (file == NULL)
+		return FALSE;
+
+	if (link_id != NULL) {
+		url = g_strconcat ("ghelp://", file, "?", link_id, NULL);
+	} else {
+		url = g_strconcat ("ghelp://", file, NULL);	
+	}
+
+	command = g_strconcat ("gnome-open ", url, NULL);
+			
+	retval = g_spawn_command_line_sync (command,
+					    NULL,
+					    NULL,
+					    &exit_status,
+					    &error);
+
+	if (!retval) {
+		g_error_free (error);
+		error = NULL;
+	}		
+	
+	g_free (command);
+	g_free (file);
+	g_free (url);
+	
+	return retval && !exit_status;
+}
+
 static void
 gpw_refresh_title (GladeProjectWindow *gpw)
 {
@@ -104,17 +199,17 @@ gpw_refresh_title (GladeProjectWindow *gpw)
 		name = glade_project_display_name (project, TRUE, FALSE, FALSE);
 		
 		if (project->readonly != FALSE)
-			title = g_strdup_printf ("%s %s - %s", name,
-						 READONLY_INDICATOR, g_get_application_name ());
+			title = g_strdup_printf ("%s %s", name, READONLY_INDICATOR);
 		else
-			title = g_strdup_printf ("%s - %s", name,
-						 g_get_application_name ());
+			title = g_strdup_printf ("%s", name);
 		
 		g_free (name);
 	}
 	else
-		title = g_strdup_printf ("%s", g_get_application_name ());
-
+	{
+		title = g_strdup (_("User Interface Designer"));
+	}
+	
 	gtk_window_set_title (GTK_WINDOW (gpw->priv->window), title);
 
 	g_free (title);
@@ -655,9 +750,52 @@ gpw_open_cb (GtkAction *action, GladeProjectWindow *gpw)
 static void
 gpw_save (GladeProjectWindow *gpw, GladeProject *project, const gchar *path)
 {
-	GError  *error = NULL;
-	gchar   *display_name, *display_path = g_strdup (path);
+	GError   *error = NULL;
+	gchar    *display_name, *display_path = g_strdup (path);
+	time_t    mtime;
+	GtkWidget *dialog;
+	GtkWidget *button;
+	gint       response;
 
+	/* check for external modification to the project file */
+	mtime = glade_util_get_file_mtime (project->path, NULL);
+	
+	if (mtime > glade_project_get_file_mtime (project)) {
+	
+		dialog = gtk_message_dialog_new (GTK_WINDOW (gpw->priv->window),
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_WARNING,
+						 GTK_BUTTONS_NONE,
+						 _("The file %s has been modified since reading it"),
+						 project->path);
+						 
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), 				 
+							  _("If you save it, all the external changes could be lost. Save it anyway?"));
+							  
+		gtk_window_set_title (GTK_WINDOW (dialog), "");
+		
+	        button = gtk_button_new_with_mnemonic (_("_Save Anyway"));
+	        gtk_button_set_image (GTK_BUTTON (button),
+	        		      gtk_image_new_from_stock (GTK_STOCK_SAVE,
+	        		      				GTK_ICON_SIZE_BUTTON));
+	        gtk_widget_show (button);
+
+		gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_ACCEPT);	        		      			
+	        gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Don't Save"), GTK_RESPONSE_REJECT);			 
+						 
+		gtk_dialog_set_default_response	(GTK_DIALOG (dialog), GTK_RESPONSE_REJECT);
+		
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+		
+		gtk_widget_destroy (dialog);
+		
+		if (response == GTK_RESPONSE_REJECT)
+		{
+			g_free (display_path);
+			return;
+		}
+	}
+		  
 	/* Interestingly; we cannot use `path' after glade_project_reset_path
 	 * because we are getting called with project->path as an argument.
 	 */
@@ -1032,48 +1170,6 @@ gpw_hide_window_on_delete (GtkWidget *window, gpointer not_used, GtkUIManager *u
 	return TRUE;
 }
 
-static void
-gpw_construct_console (GladeProjectWindow *gpw)
-{
-	GtkWidget *window, *console, *notebook;
-	GList *list, *l;
-	
-	g_return_if_fail (gpw != NULL);
-
-	window = gpw->priv->console = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-
-	gtk_window_set_title (GTK_WINDOW (window), _("Glade's Script Console"));
-	gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
-	gtk_widget_set_size_request (window, 640, 480);
-	
-	notebook = gtk_notebook_new ();
-	gtk_container_add (GTK_CONTAINER (window), notebook);
-	gtk_widget_show (notebook);
-	
-	for (list = l = glade_binding_get_all(); l && l->data; l = g_list_next (l))
-	{
-		GladeBinding *binding = l->data;
-		
-		if ((console = glade_binding_console_new (binding)))
-		{
-			gtk_notebook_append_page (GTK_NOTEBOOK (notebook), console,
-						  gtk_label_new (glade_binding_get_name (binding)));
-			gtk_widget_show (console);
-		}
-	}
-
-	if (list == NULL)
-		gtk_widget_set_sensitive (gtk_ui_manager_get_widget 
-					  (gpw->priv->ui, "/MenuBar/ViewMenu/Console"),
-					  FALSE);
-
-	g_list_free (list);
-	
-	/* Delete event, don't destroy it */
-	g_signal_connect (window, "delete-event",
-			  G_CALLBACK (gpw_hide_window_on_delete), gpw->priv->ui);
-}
-
 static void
 gpw_doc_search_cb (GladeEditor        *editor,
 		   const gchar        *book,
@@ -1140,16 +1236,6 @@ gpw_notebook_switch_page_cb (GtkNotebook *notebook,
 
 }
 
-static void
-gpw_show_console_cb (GtkAction *action, GladeProjectWindow *gpw)
-{
-	g_return_if_fail (gpw != NULL);
-
-	gtk_widget_show (gpw->priv->console);
-
-	gtk_window_present (GTK_WINDOW (gpw->priv->console));
-}
-
 static void
 gpw_notebook_tab_added_cb (GtkNotebook *notebook,
 			   GladeDesignView *view,
@@ -1303,10 +1389,78 @@ gpw_toggle_editor_help_cb (GtkAction *action, GladeProjectWindow *gpw)
 		glade_editor_hide_context_info (glade_app_get_editor ());
 }
 
-static void 
-gpw_documentation_cb (GtkAction *action, GladeProjectWindow *gpw)
+static void
+gpw_show_help_cb (GtkAction *action, GladeProjectWindow *gpw)
 {
-	glade_util_search_devhelp ("gladeui", NULL, NULL);
+	GtkWidget *dialog;
+	gboolean retval;
+	
+	retval = glade_project_window_help_show (NULL);
+	if (retval)
+		return;
+	
+	/* fallback to displaying online user manual */ 
+	retval = glade_util_url_show (GLADE_URL_USER_MANUAL);	
+
+	if (!retval)
+	{
+		dialog = gtk_message_dialog_new (GTK_WINDOW (gpw->priv->window),
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_OK,
+						 _("Could not display the online user manual"));
+						 
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("No suitable web browser executable could be found "
+							    "to be executed and to display the URL: %s"),
+							    GLADE_URL_USER_MANUAL);
+						 	
+		gtk_window_set_title (GTK_WINDOW (dialog), "");
+
+		g_signal_connect_swapped (dialog, "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  dialog);
+
+		gtk_widget_show (dialog);
+		
+	}
+}
+
+static void 
+gpw_show_developer_manual_cb (GtkAction *action, GladeProjectWindow *gpw)
+{
+	GtkWidget *dialog;
+	gboolean retval;
+	
+	if (glade_util_have_devhelp ())
+	{
+		glade_util_search_devhelp ("gladeui", NULL, NULL);
+		return;	
+	}
+	
+	retval = glade_util_url_show (GLADE_URL_DEVELOPER_MANUAL);	
+
+	if (!retval)
+	{
+		dialog = gtk_message_dialog_new (GTK_WINDOW (gpw->priv->window),
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_OK,
+						 _("Could not display the online developer reference manual"));
+						 
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  _("No suitable web browser executable could be found "
+							    "to be executed and to display the URL: %s"),
+							    GLADE_URL_DEVELOPER_MANUAL);
+						 	
+		gtk_window_set_title (GTK_WINDOW (dialog), "");
+
+		g_signal_connect_swapped (dialog, "response",
+					  G_CALLBACK (gtk_widget_destroy),
+					  dialog);
+
+		gtk_widget_show (dialog);
+	}	
 }
 
 static void 
@@ -1324,33 +1478,6 @@ gpw_about_cb (GtkAction *action, GladeProjectWindow *gpw)
 		  "Vincent Geddes <vincent.geddes@gmail.com>",
 		  NULL };
 
-	static const gchar translators[] =
-		"Fatih Demir <kabalak@gtranslator.org>\n"
-		"Christian Rose <menthos@menthos.com>\n"
-		"Pablo Saratxaga <pablo@mandrakesoft.com>\n"
-		"Duarte Loreto <happyguy_pt@hotmail.com>\n"
-		"Zbigniew Chyla <cyba@gnome.pl>\n"
-		"Hasbullah Bin Pit <sebol@ikhlas.com>\n"
-		"Takeshi AIHANA <aihana@gnome.gr.jp>\n"
-		"Kjartan Maraas <kmaraas@gnome.org>\n"
-		"Carlos Perell Marn <carlos@gnome-db.org>\n"
-		"Valek Filippov <frob@df.ru>\n"
-		"Stanislav Visnovsky <visnovsky@nenya.ms.mff.cuni.cz>\n"
-		"Christophe Merlet <christophe@merlet.net>\n"
-		"Funda Wang <fundawang@linux.net.cn>\n"
-		"Francisco Javier F. Serrador <serrador@cvs.gnome.org>\n"
-		"Adam Weinberger <adamw@gnome.org>\n"
-		"Raphael Higino <raphaelh@cvs.gnome.org>\n"
-		"Clytie Siddall <clytie@riverland.net.au>\n"
-		"Jordi Mas <jmas@softcatala.org>\n"
-		"Vincent van Adrighem <adrighem@gnome.org>\n"
-		"Daniel Nylander <po@danielnylander.se>\n";
-
-	static const gchar comments[] =
-		N_("Glade is a user interface designer for GTK+ and GNOME.\n"
-		  "This version is a rewrite of the Glade 2 version, "
-		  "originally created by Damon Chaplin\n");
-
 	static const gchar license[] =
 		N_("This program is free software; you can redistribute it and/or modify\n"
 		  "it under the terms of the GNU General Public License as\n"
@@ -1374,9 +1501,9 @@ gpw_about_cb (GtkAction *action, GladeProjectWindow *gpw)
 			       "name", g_get_application_name (),
 			       "logo-icon-name", "glade-3",
 			       "authors", authors,
-			       "translator-credits", translators,
-			       "comments", comments,
-			       "license", license,
+			       "translator-credits", _("translator-credits"),
+			       "comments", _("A user interface designer for GTK+ and GNOME."),
+			       "license", _(license),
 			       "copyright", copyright,
 			       "version", PACKAGE_VERSION,
 			       "website", "http://glade.gnome.org",
@@ -1408,7 +1535,6 @@ static const gchar *ui_info =
 "    </menu>\n"
 "    <menu action='ViewMenu'>\n"
 "      <menuitem action='Clipboard'/>\n"
-"      <menuitem action='Console'/>\n"
 "      <separator/>\n"
 "      <menu action='PaletteAppearance'>\n"
 "        <menuitem action='IconsAndLabels'/>\n"
@@ -1426,7 +1552,8 @@ static const gchar *ui_info =
 "      <placeholder name='ProjectsListPlaceholder'/>\n"
 "    </menu>\n"
 "    <menu action='HelpMenu'>\n"
-"      <menuitem action='Manual'/>\n"
+"      <menuitem action='HelpContents'/>\n"
+"      <menuitem action='DeveloperReference'/>\n"
 "      <separator/>\n"
 "      <menuitem action='About'/>\n"
 "    </menu>\n"
@@ -1456,7 +1583,7 @@ static GtkActionEntry static_entries[] = {
 	{ "New", GTK_STOCK_NEW, N_("_New"), "<control>N",
 	  N_("Create a new project"), G_CALLBACK (gpw_new_cb) },
 	
-	{ "Open", GTK_STOCK_OPEN, N_("_Open"),"<control>O",
+	{ "Open", GTK_STOCK_OPEN, N_("_Open\342\200\246"),"<control>O",
 	  N_("Open a project"), G_CALLBACK (gpw_open_cb) },
 
 	{ "OpenRecent", NULL, N_("Open _Recent") },	
@@ -1465,15 +1592,19 @@ static GtkActionEntry static_entries[] = {
 	  N_("Quit the program"), G_CALLBACK (gpw_quit_cb) },
 
 	/* ViewMenu */
-	{ "PaletteAppearance", NULL, "Palette _Appearance" },
+	{ "PaletteAppearance", NULL, N_("Palette _Appearance") },
 	
 	/* HelpMenu */
 	{ "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
-	  N_("Shows the About Dialog"), G_CALLBACK (gpw_about_cb) },
+	  N_("About this application"), G_CALLBACK (gpw_about_cb) },
 
-	{ "Manual", NULL, N_("_Documentation"), NULL,
-	  N_("Documentation about Glade"), G_CALLBACK (gpw_documentation_cb) }
+	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	  N_("Display the user manual"), G_CALLBACK (gpw_show_help_cb) },
+
+	{ "DeveloperReference", NULL, N_("_Developer Reference"), NULL,
+	  N_("Display the developer reference manual"), G_CALLBACK (gpw_show_developer_manual_cb) }
 };
+
 static guint n_static_entries = G_N_ELEMENTS (static_entries);
 
 static GtkActionEntry project_entries[] = {
@@ -1513,10 +1644,6 @@ static GtkActionEntry project_entries[] = {
 	  N_("Show the clipboard"),
 	  G_CALLBACK (gpw_show_clipboard_cb) },
 	  
-	{ "Console", NULL, N_("C_onsole"), NULL,
-	  N_("Show Script-do console"),
-	  G_CALLBACK (gpw_show_console_cb) },
-	  
 	/* ProjectsMenu */
 	{ "PreviousProject", NULL, N_("_Previous Project"), "<control>Page_Up",
 	  N_("Activate previous project"), G_CALLBACK (glade_project_window_previous_project_cb) },
@@ -1746,7 +1873,7 @@ create_selector_tool_button (GtkToolbar *toolbar)
 	GtkWidget    *image;
 	gchar        *image_path;
 	
-	image_path = g_build_filename (glade_pixmaps_dir, "selector.png", NULL);
+	image_path = g_build_filename (glade_app_get_pixmaps_dir (), "selector.png", NULL);
 	image = gtk_image_new_from_file (image_path);
 	g_free (image_path);
 	
@@ -1754,10 +1881,11 @@ create_selector_tool_button (GtkToolbar *toolbar)
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (button), TRUE);
 	
 	gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (button), image);
+	gtk_tool_button_set_label (GTK_TOOL_BUTTON (button), _("Select Widgets"));
 	
 	gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (button),
 				   toolbar->tooltips,
-				   _("Select a widget"),
+				   _("Select widgets in the workspace"),
 				   NULL);
 	
 	gtk_widget_show (GTK_WIDGET (button));
@@ -1766,6 +1894,24 @@ create_selector_tool_button (GtkToolbar *toolbar)
 	return GTK_WIDGET (button);
 }
 
+static gint
+gpw_hijack_editor_key_press (GtkWidget          *win, 
+			     GdkEventKey        *event, 
+			     GladeProjectWindow *gpw)
+{
+	if (GTK_WINDOW (win)->focus_widget &&
+	    (event->keyval == GDK_Delete || /* Filter Delete from accelerator keys */
+	     ((event->state & GDK_CONTROL_MASK) && /* CNTL keys... */
+	      ((event->keyval == GDK_c || event->keyval == GDK_C) || /* CNTL-C (copy)  */
+	       (event->keyval == GDK_x || event->keyval == GDK_X) || /* CNTL-X (cut)   */
+	       (event->keyval == GDK_v || event->keyval == GDK_V))))) /* CNTL-V (paste) */
+	{
+		return gtk_widget_event (GTK_WINDOW (win)->focus_widget, 
+					 (GdkEvent *)event);
+	}
+	return FALSE;
+}
+
 static void
 glade_project_window_create (GladeProjectWindow *gpw)
 {
@@ -1778,7 +1924,7 @@ glade_project_window_create (GladeProjectWindow *gpw)
 	GtkWidget *toolbar;
 	GladeProjectView *project_view;
 	GtkWidget *statusbar;
-	GtkWidget *editor_item, *docs_item;
+	GtkWidget *editor_item;
 	GtkWidget *palette;
 	GtkWidget *editor;
 	GtkWidget *dockitem;
@@ -1809,6 +1955,8 @@ glade_project_window_create (GladeProjectWindow *gpw)
 	hpaned2 = gtk_hpaned_new ();
 	vpaned = gtk_vpaned_new ();
 
+	gtk_container_set_border_width (GTK_CONTAINER (hpaned1), 2);
+
 	gtk_box_pack_start (GTK_BOX (vbox), hpaned1, TRUE, TRUE, 0);
 	gtk_paned_pack1 (GTK_PANED (hpaned1), hpaned2, TRUE, FALSE);
 	gtk_paned_pack2 (GTK_PANED (hpaned1), vpaned, FALSE, FALSE);
@@ -1864,15 +2012,8 @@ glade_project_window_create (GladeProjectWindow *gpw)
 	/* devhelp */
 	editor_item = gtk_ui_manager_get_widget (gpw->priv->ui,
 						 "/MenuBar/ViewMenu/PropertyEditorHelp");
-	docs_item = gtk_ui_manager_get_widget (gpw->priv->ui,
-					       "/MenuBar/HelpMenu/Manual");
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (editor_item), FALSE);
 
 	gtk_widget_set_sensitive (editor_item, FALSE);
-	gtk_widget_set_sensitive (docs_item, FALSE);
-	
-	/* Console */
-	gpw_construct_console (gpw);
 	
 	/* recent files */	
 	gpw->priv->recent_manager = gtk_recent_manager_get_for_screen (gtk_widget_get_screen (gpw->priv->window));
@@ -1938,6 +2079,10 @@ glade_project_window_create (GladeProjectWindow *gpw)
 	g_signal_connect (gpw->priv->window, "window-state-event",
 			  G_CALLBACK (gpw_window_state_event_cb),
 			  gpw);
+
+	g_signal_connect (G_OBJECT (gpw->priv->window), "key-press-event",
+			  G_CALLBACK (gpw_hijack_editor_key_press), gpw);
+
 }
 
 static void
@@ -2095,15 +2240,15 @@ glade_project_window_finalize (GObject *object)
 }
 
 static void
-glade_project_window_class_init (GladeProjectWindowClass * class)
+glade_project_window_class_init (GladeProjectWindowClass * klass)
 {
 	GObjectClass *object_class;
 	GladeAppClass *app_class;
-	g_return_if_fail (class != NULL);
+	g_return_if_fail (klass != NULL);
 
-	parent_class = g_type_class_peek_parent (class);
-	object_class = G_OBJECT_CLASS  (class);
-	app_class    = GLADE_APP_CLASS (class);
+	parent_class = g_type_class_peek_parent (klass);
+	object_class = G_OBJECT_CLASS  (klass);
+	app_class    = GLADE_APP_CLASS (klass);
 
 	object_class->finalize = glade_project_window_finalize;
 
@@ -2119,7 +2264,9 @@ glade_project_window_init (GladeProjectWindow *gpw)
 	
 	gpw->priv->label = NULL;
 	gpw->priv->default_path = NULL;
-
+	
+	gtk_about_dialog_set_url_hook ((GtkAboutDialogActivateLinkFunc) about_dialog_activate_link_func, gpw, NULL);
+	
 }
 
 GladeProjectWindow *
@@ -2149,12 +2296,10 @@ glade_project_window_new (void)
 void
 glade_project_window_check_devhelp (GladeProjectWindow *gpw)
 {
-	GtkWidget *editor_item, *docs_item;
+	GtkWidget *editor_item;
 	
 	editor_item = gtk_ui_manager_get_widget (gpw->priv->ui,
-						 "/MenuBar/ViewMenu/PropertyEditorHelp");
-	docs_item = gtk_ui_manager_get_widget (gpw->priv->ui,
-					       "/MenuBar/HelpMenu/Manual");
+						 "/MenuBar/ViewMenu/PropertyEditorHelp");	
 
 	if (glade_util_have_devhelp ())
 	{
@@ -2168,11 +2313,9 @@ glade_project_window_check_devhelp (GladeProjectWindow *gpw)
 				  G_CALLBACK (gpw_doc_search_cb), gpw);
 		
 		gtk_widget_set_sensitive (editor_item, TRUE);
-		gtk_widget_set_sensitive (docs_item, TRUE);
 	}
 	else
 	{
 		gtk_widget_set_sensitive (editor_item, FALSE);
-		gtk_widget_set_sensitive (docs_item, FALSE);
 	}
 }
